      subroutine jlmcen
c     version as of 3/19/88.
c
c     ******************************************************************
c
c     calculates real and imaginary parts of central potential
c     using jlm prescription with improved lda
c     ref: phys. rev. c16(1977)80 
c     uses the improved lda evaluated  at the projectile position (r')
c     as in PRC 58, 1118 (1998) and PRC 63, 024607 (2001)
c
c     if kmw is nonzero, imaginary potentials are multiplied by
c     a k-mass factor, which is a correction to the original jlm work.
c     see ref 41,42 of PRC 58, 1118 (1998) 
c
c     ******************************************************************
c
      implicit none
 
      include 'mai1_com.inc'
      include 'mai2_com.inc'
      include 'gsdn_com.inc'
      include 'skch_com.inc'
      include 'jlms_com.inc'
      include 'kmas_com.inc'
      include 'alfs_com.inc'
      include 'lams_com.inc'
      include 'vang1_com.inc' 
      include 'gl_com.inc'
      include 'pots_com.inc'
      include 'vcinp_com.inc'

      real*8 temp(32)
      real*8 str(200,32,4),st(4)
      real*8 dc(4,4),fc(4,4)
      real*8 fro(200),fio(200),gro(200),gio(200)

      real*8 capd,r,cen,vzero,ren,redms,akmass,wzero,rho,alf
      real*8 aaf,eef,xfr1,xfr2,eps1,eps2,eps,e,vcorr,f,emass,sdot
      real*8 tau3
      integer*4 i,j,ita,n,ii,jj,ipol
      integer*4 ix,ity,nblk8,il
c
c
c     input arrays of coefficients in block data


      tau3=2.d0*(.5d0-zp)

      call xform

      do  i=1,200
         vci(i)=0.d0
         vcr(i)=0.d0
      enddo

c     typo in PRC 58 1118 (1998) v1.01
      capd=126.25d0

      do  i=1,4
         do  j=1,4
            dc(i,j)=dhc(i,j)
            fc(i,j)=fhc(i,j)
         enddo
      enddo
      
c     loop on the angular coordinate theta (ita)
c     for this spherical version npgl=1
c     this loop is here only for historical reasons since the
c     present spherical code is a version of our deformed code
c     that is restricted to the spherical symetry (l=0)
      do 132 ita=1,npgl
      r=h  
c     loop on the radial coordinate r
      do 32 n=1,npts
      cen=0.d0
      vzero=0.d0
      ren=0.d0
      redms=1.d0
      akmass=1.d0
      wzero=0.d0
      rho=vang(n,ita)
      alf=valf(n,ita) 


c      
c      calculate the Fermi energy eps using the modified expression
c     of PRC 58,1118 (1998). bug in v1.0, corrected in v1.01
      aaf=2.d0
      eef=9.d0
      xfr1=1./(1.+exp((ecm-eef)/aaf))
      xfr2=1.-xfr1
      eps1=-22.d0-rho*(298.52d0-3760.23d0*rho+12435.82d0*rho**2)
      eps2=rho*(-510.8d0+3222.d0*rho-6250.d0*rho**2)
      eps=eps1*xfr1+eps2*xfr2

 24   continue

      e=ecm-vcorr(r)
      f=e
      if(icorv.eq.0)e=ecm
      if(icorw.eq.0)f=ecm

      do  ii=1,3
         do  jj=1,3
            vzero=vzero+ac(ii,jj)*(rho**ii)*(e**(jj-1))
            redms=redms-(jj-1)*ac(ii,jj)*(rho**ii)*(e**(jj-2))
            ren=ren+bc(ii,jj)*(rho**ii)*(e**(jj-1))
            akmass=akmass-cc(ii,jj)*(rho**ii)*(e**(jj-1))
         enddo
      enddo

      ekmr(n)=akmass
      ekmi(n)=0.d0
      emass=redms/akmass

      do i=1,4 
         do j=1,4
            wzero=wzero
     &            +dc(i,j)*(rho**i)*(f**(j-1))/(1.d0+capd/((f-eps)**2))
            cen=cen+fc(i,j)*(rho**i)*(f**(j-1))/(1.d0+1.d0/(f-eps))
         enddo
      enddo

      fr(n)=al0r*xlv*vzero
      fi(n)=al0i*xlw*wzero
      gr(n)=altr*xlv*akmass*ren
      gi(n)=alti*xlw*cen/emass

      if(kmw.eq.0) go to 30
      fi(n)=akmass*fi(n)
      gi(n)=akmass*gi(n)
 30   continue
 32   r=r+h

      do n=1,npts
         rho=vang(n,ita)
         alf=valf(n,ita)
         
         str(n,ita,1)=fr(n)
         str(n,ita,3)=fi(n)
         str(n,ita,2)=alf*gr(n)
         str(n,ita,4)=alf*gi(n)
      enddo
 132  continue

c     pot diagonal l=0
      do ix=1,npts 
         do ity=1,4
            do ita=1,npgl
               temp(ita)=str(ix,ita,ity) 
            enddo
            st(ity)=sdot(npgl,temp,1,wg,1)
         enddo
         vcentr(ix,1)=st(1)+tau3*st(2)      
         vcenti(ix,1)=st(3)+tau3*st(4)      
      enddo

      do ipol=1,1
         do i=1,npts
               fr(i)=vcentr(i,1)
               gr(i)=vcentr(i,1)
               fi(i)=vcenti(i,1)
               gi(i)=vcenti(i,1)
         enddo
         nblk8 = npts/8 
         il=2*ipol-2
         call convolbesl0(fr,gr,fro,gro,nblk8,tjlmr)
         call convolbesl0(fi,gi,fio,gio,nblk8,tjlmi)

         do i=1,npts  
               vcentr(i,1)=fro(i)
               vcenti(i,1)=fio(i)
               vcr(i)=vcentr(i,1)
               vci(i)=vcenti(i,1)
         enddo
      enddo



      return
c

      end
